# Note: package is python 3 only
%global srcname pyphi

%bcond_with tests

%global desc %{expand: \
PyPhi is a Python library for computing integrated information, and the
associated quantities and objects.

If you use this code, please cite the manuscript:

Mayner WGP, Marshall W, Albantakis L, Findlay G, Marchman R, Tononi G (2017).
PyPhi: A toolbox for integrated information. arXiv:1712.09644 [q-bio.NC].

The manuscript is available at https://arxiv.org/abs/1712.09644.}

%{?python_enable_dependency_generator}

Name:           python-%{srcname}
Version:        1.1.0
Release:        2%{?dist}
Summary:        A library for computing integrated information

License:        GPLv3
URL:            https://pypi.python.org/pypi/%{srcname}
Source0:        https://github.com/wmayner/%{srcname}/archive/%{version}/%{srcname}-%{version}.tar.gz
BuildArch:      noarch

%description
%{desc}

%package -n python3-%{srcname}
Summary:        %{summary}
BuildRequires:  python3-devel
# To build docs, and run tests
BuildRequires:  %{py3_dist sphinx}
BuildRequires:  %{py3_dist setuptools}
BuildRequires:  %{py3_dist wheel}
BuildRequires:  %{py3_dist pyyaml}
BuildRequires:  %{py3_dist tqdm}
BuildRequires:  %{py3_dist numpy}
BuildRequires:  %{py3_dist pytest}
BuildRequires:  %{py3_dist pyyaml}
BuildRequires:  %{py3_dist redis}
BuildRequires:  %{py3_dist tblib}
BuildRequires:  %{py3_dist tqdm}
BuildRequires:  %{py3_dist psutil}
BuildRequires:  %{py3_dist asv}
BuildRequires:  %{py3_dist pyemd}
BuildRequires:  %{py3_dist scipy}
BuildRequires:  %{py3_dist joblib}
BuildRequires:  %{py3_dist pymongo}
BuildRequires:  %{py3_dist decorator}

%{?python_provide:%python_provide python3-%{srcname}}

%description -n python3-%{srcname}
%{desc}

%package doc
Summary:        %{summary}

%description doc
%{desc}


%prep
%autosetup -n %{srcname}-%{version}

# sphinx 1.3+, it's an extension
# Also sent upstream: https://github.com/wmayner/pyphi/pull/22
sed -i "s/sphinxcontrib.napoleon/sphinx.ext.napoleon/" docs/conf.py

find pyphi -name "*.py" -exec sed -i '/#!\/usr\/bin\/env python3/ d' '{}' \;

%build
%py3_build

pushd docs
    make SPHINXBUILD=sphinx-build-3 html
    rm -rf _build/html/.doctrees
    rm -rf _build/html/.buildinfo
popd

%install
%py3_install

%check
%if %{with tests}
py.test-%{python3_version}
%endif

%files -n python3-%{srcname}
%license LICENSE.md
%doc README.md CHANGELOG.md CACHING.rst redis.conf
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/%{srcname}-%{version}-py3.?.egg-info

%files doc
%license LICENSE.md
%doc docs/_build/html/

%changelog
* Mon Nov 19 2018 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 1.1.0-2
- Update license
- Fix doc generation
- Correct rpmlint errors

* Wed Nov 14 2018 Ankur Sinha <ankursinha AT fedoraproject DOT org> - 1.1.0-1
- Initial rpm build
